@@ -172,24 +172,6 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_GPU_DEFAULT_CORE_THRESHOLD);
     MAKE_SIGNAL(NV_CTRL_GPU_MAX_CORE_THRESHOLD);
     MAKE_SIGNAL(NV_CTRL_AMBIENT_TEMPERATURE);
-    MAKE_SIGNAL(NV_CTRL_GVO_SUPPORTED);
-    MAKE_SIGNAL(NV_CTRL_GVO_SYNC_MODE);
-    MAKE_SIGNAL(NV_CTRL_GVO_SYNC_SOURCE);
-    MAKE_SIGNAL(NV_CTRL_GVIO_REQUESTED_VIDEO_FORMAT);
-    MAKE_SIGNAL(NV_CTRL_GVIO_DETECTED_VIDEO_FORMAT);
-    MAKE_SIGNAL(NV_CTRL_GVO_DATA_FORMAT);
-    MAKE_SIGNAL(NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECTED);
-    MAKE_SIGNAL(NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECT_MODE);
-    MAKE_SIGNAL(NV_CTRL_GVO_SDI_SYNC_INPUT_DETECTED);
-    MAKE_SIGNAL(NV_CTRL_GVO_VIDEO_OUTPUTS);
-    MAKE_SIGNAL(NV_CTRL_GVO_FIRMWARE_VERSION);
-    MAKE_SIGNAL(NV_CTRL_GVO_SYNC_DELAY_PIXELS);
-    MAKE_SIGNAL(NV_CTRL_GVO_SYNC_DELAY_LINES);
-    MAKE_SIGNAL(NV_CTRL_GVO_INPUT_VIDEO_FORMAT_REACQUIRE);
-    MAKE_SIGNAL(NV_CTRL_GVO_GLX_LOCKED);
-    MAKE_SIGNAL(NV_CTRL_GVIO_VIDEO_FORMAT_WIDTH);
-    MAKE_SIGNAL(NV_CTRL_GVIO_VIDEO_FORMAT_HEIGHT);
-    MAKE_SIGNAL(NV_CTRL_GVIO_VIDEO_FORMAT_REFRESH_RATE);
     MAKE_SIGNAL(NV_CTRL_FLATPANEL_LINK);
     MAKE_SIGNAL(NV_CTRL_USE_HOUSE_SYNC);
     MAKE_SIGNAL(NV_CTRL_IMAGE_SETTINGS);
@@ -197,8 +179,6 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_BUS_RATE);
     MAKE_SIGNAL(NV_CTRL_SHOW_SLI_VISUAL_INDICATOR);
     MAKE_SIGNAL(NV_CTRL_XV_SYNC_TO_DISPLAY);
-    MAKE_SIGNAL(NV_CTRL_GVO_OVERRIDE_HW_CSC);
-    MAKE_SIGNAL(NV_CTRL_GVO_COMPOSITE_TERMINATION);
     MAKE_SIGNAL(NV_CTRL_ASSOCIATED_DISPLAY_DEVICES);
     MAKE_SIGNAL(NV_CTRL_FRAMELOCK_SLAVES);
     MAKE_SIGNAL(NV_CTRL_FRAMELOCK_MASTERABLE);
@@ -227,15 +207,8 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_DFP_SCALING_ACTIVE);
     MAKE_SIGNAL(NV_CTRL_FSAA_APPLICATION_ENHANCED);
     MAKE_SIGNAL(NV_CTRL_FRAMELOCK_SYNC_RATE_4);
-    MAKE_SIGNAL(NV_CTRL_GVO_LOCK_OWNER);
     MAKE_SIGNAL(NV_CTRL_NUM_GPU_ERRORS_RECOVERED);
     MAKE_SIGNAL(NV_CTRL_REFRESH_RATE_3);
-    MAKE_SIGNAL(NV_CTRL_GVO_OUTPUT_VIDEO_LOCKED);
-    MAKE_SIGNAL(NV_CTRL_GVO_SYNC_LOCK_STATUS);
-    MAKE_SIGNAL(NV_CTRL_GVO_ANC_TIME_CODE_GENERATION);
-    MAKE_SIGNAL(NV_CTRL_GVO_COMPOSITE);
-    MAKE_SIGNAL(NV_CTRL_GVO_COMPOSITE_ALPHA_KEY);
-    MAKE_SIGNAL(NV_CTRL_GVO_COMPOSITE_NUM_KEY_RANGES);
     MAKE_SIGNAL(NV_CTRL_NOTEBOOK_DISPLAY_CHANGE_LID_EVENT);
     MAKE_SIGNAL(NV_CTRL_MODE_SET_EVENT);
     MAKE_SIGNAL(NV_CTRL_OPENGL_AA_LINE_GAMMA_VALUE);
@@ -243,27 +216,12 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_DISPLAYPORT_LINK_RATE);
     MAKE_SIGNAL(NV_CTRL_STEREO_EYES_EXCHANGE);
     MAKE_SIGNAL(NV_CTRL_NO_SCANOUT);
-    MAKE_SIGNAL(NV_CTRL_GVO_CSC_CHANGED_EVENT);
     MAKE_SIGNAL(NV_CTRL_X_SERVER_UNIQUE_ID);
     MAKE_SIGNAL(NV_CTRL_PIXMAP_CACHE);
     MAKE_SIGNAL(NV_CTRL_PIXMAP_CACHE_ROUNDING_SIZE_KB);
-    MAKE_SIGNAL(NV_CTRL_IS_GVO_DISPLAY);
     MAKE_SIGNAL(NV_CTRL_PCI_ID);
-    MAKE_SIGNAL(NV_CTRL_GVO_FULL_RANGE_COLOR);
     MAKE_SIGNAL(NV_CTRL_SLI_MOSAIC_MODE_AVAILABLE);
-    MAKE_SIGNAL(NV_CTRL_GVO_ENABLE_RGB_DATA);
     MAKE_SIGNAL(NV_CTRL_IMAGE_SHARPENING_DEFAULT);
-    MAKE_SIGNAL(NV_CTRL_GVI_NUM_JACKS);
-    MAKE_SIGNAL(NV_CTRL_GVI_MAX_LINKS_PER_STREAM);
-    MAKE_SIGNAL(NV_CTRL_GVI_DETECTED_CHANNEL_BITS_PER_COMPONENT);
-    MAKE_SIGNAL(NV_CTRL_GVI_REQUESTED_STREAM_BITS_PER_COMPONENT);
-    MAKE_SIGNAL(NV_CTRL_GVI_DETECTED_CHANNEL_COMPONENT_SAMPLING);
-    MAKE_SIGNAL(NV_CTRL_GVI_REQUESTED_STREAM_COMPONENT_SAMPLING);
-    MAKE_SIGNAL(NV_CTRL_GVI_REQUESTED_STREAM_CHROMA_EXPAND);
-    MAKE_SIGNAL(NV_CTRL_GVI_DETECTED_CHANNEL_COLOR_SPACE);
-    MAKE_SIGNAL(NV_CTRL_GVI_DETECTED_CHANNEL_LINK_ID);
-    MAKE_SIGNAL(NV_CTRL_GVI_DETECTED_CHANNEL_SMPTE352_IDENTIFIER);
-    MAKE_SIGNAL(NV_CTRL_GVI_GLOBAL_IDENTIFIER);
     MAKE_SIGNAL(NV_CTRL_FRAMELOCK_SYNC_DELAY_RESOLUTION);
     MAKE_SIGNAL(NV_CTRL_GPU_COOLER_MANUAL_CONTROL);
     MAKE_SIGNAL(NV_CTRL_THERMAL_COOLER_LEVEL);
@@ -272,17 +230,11 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_THERMAL_COOLER_TARGET);
     MAKE_SIGNAL(NV_CTRL_GPU_ECC_CONFIGURATION);
     MAKE_SIGNAL(NV_CTRL_GPU_POWER_MIZER_MODE);
-    MAKE_SIGNAL(NV_CTRL_GVI_SYNC_OUTPUT_FORMAT);
-    MAKE_SIGNAL(NV_CTRL_GVI_MAX_CHANNELS_PER_JACK);
-    MAKE_SIGNAL(NV_CTRL_GVI_MAX_STREAMS);
-    MAKE_SIGNAL(NV_CTRL_GVI_NUM_CAPTURE_SURFACES);
     MAKE_SIGNAL(NV_CTRL_OVERSCAN_COMPENSATION);
     MAKE_SIGNAL(NV_CTRL_GPU_PCIE_GENERATION);
-    MAKE_SIGNAL(NV_CTRL_GVI_BOUND_GPU);
     MAKE_SIGNAL(NV_CTRL_ACCELERATE_TRAPEZOIDS);
     MAKE_SIGNAL(NV_CTRL_GPU_CORES);
     MAKE_SIGNAL(NV_CTRL_GPU_MEMORY_BUS_WIDTH);
-    MAKE_SIGNAL(NV_CTRL_GVI_TEST_MODE);
     MAKE_SIGNAL(NV_CTRL_COLOR_SPACE);
     MAKE_SIGNAL(NV_CTRL_COLOR_RANGE);
     MAKE_SIGNAL(NV_CTRL_CURRENT_COLOR_SPACE);
@@ -298,20 +250,17 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_THERMAL_SENSOR_TARGET);
     MAKE_SIGNAL(NV_CTRL_SHOW_MULTIGPU_VISUAL_INDICATOR);
     MAKE_SIGNAL(NV_CTRL_GPU_CURRENT_PROCESSOR_CLOCK_FREQS);
-    MAKE_SIGNAL(NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS);
     MAKE_SIGNAL(NV_CTRL_GPU_PCIE_MAX_LINK_SPEED);
     MAKE_SIGNAL(NV_CTRL_3D_VISION_PRO_TRANSCEIVER_CHANNEL);
     MAKE_SIGNAL(NV_CTRL_3D_VISION_PRO_TRANSCEIVER_MODE);
     MAKE_SIGNAL(NV_CTRL_SYNCHRONOUS_PALETTE_UPDATES);
     MAKE_SIGNAL(NV_CTRL_3D_VISION_PRO_TRANSCEIVER_CHANNEL_QUALITY);
     MAKE_SIGNAL(NV_CTRL_3D_VISION_PRO_GLASSES_MISSED_SYNC_CYCLES);
-    MAKE_SIGNAL(NV_CTRL_GVO_ANC_PARITY_COMPUTATION);
     MAKE_SIGNAL(NV_CTRL_3D_VISION_PRO_GLASSES_PAIR_EVENT);
     MAKE_SIGNAL(NV_CTRL_3D_VISION_PRO_GLASSES_UNPAIR_EVENT);
     MAKE_SIGNAL(NV_CTRL_GPU_PCIE_MAX_LINK_WIDTH);
     MAKE_SIGNAL(NV_CTRL_GPU_PCIE_CURRENT_LINK_WIDTH);
     MAKE_SIGNAL(NV_CTRL_GPU_PCIE_CURRENT_LINK_SPEED);
-    MAKE_SIGNAL(NV_CTRL_GVO_AUDIO_BLANKING);
     MAKE_SIGNAL(NV_CTRL_CURRENT_METAMODE_ID);
     MAKE_SIGNAL(NV_CTRL_DISPLAY_ENABLED);
     MAKE_SIGNAL(NV_CTRL_FRAMELOCK_INCOMING_HOUSE_SYNC_RATE);
@@ -381,21 +330,12 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_NVIDIA_DRIVER_VERSION);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_DISPLAY_DEVICE_NAME);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_TV_ENCODER_NAME);
-    MAKE_STRING_SIGNAL(NV_CTRL_STRING_GVIO_FIRMWARE_VERSION);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_CURRENT_MODELINE);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_ADD_MODELINE);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_DELETE_MODELINE);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_CURRENT_METAMODE);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_ADD_METAMODE);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_DELETE_METAMODE);
-    MAKE_STRING_SIGNAL(NV_CTRL_STRING_VCSC_PRODUCT_NAME);
-    MAKE_STRING_SIGNAL(NV_CTRL_STRING_VCSC_PRODUCT_ID);
-    MAKE_STRING_SIGNAL(NV_CTRL_STRING_VCSC_SERIAL_NUMBER);
-    MAKE_STRING_SIGNAL(NV_CTRL_STRING_VCSC_BUILD_DATE);
-    MAKE_STRING_SIGNAL(NV_CTRL_STRING_VCSC_FIRMWARE_VERSION);
-    MAKE_STRING_SIGNAL(NV_CTRL_STRING_VCSC_FIRMWARE_REVISION);
-    MAKE_STRING_SIGNAL(NV_CTRL_STRING_VCSC_HARDWARE_VERSION);
-    MAKE_STRING_SIGNAL(NV_CTRL_STRING_VCSC_HARDWARE_REVISION);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_MOVE_METAMODE);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_VALID_HORIZ_SYNC_RANGES);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_VALID_VERT_REFRESH_RANGES);
@@ -403,7 +343,6 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_NVIDIA_XINERAMA_INFO_ORDER);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_SLI_MODE);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_PERFORMANCE_MODES);
-    MAKE_STRING_SIGNAL(NV_CTRL_STRING_GVIO_VIDEO_FORMAT_NAME);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_GPU_CURRENT_CLOCK_FREQS);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_3D_VISION_PRO_GLASSES_NAME);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_CURRENT_METAMODE_VERSION_2);
@@ -440,8 +379,6 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_BINARY_SIGNAL(NV_CTRL_BINARY_DATA_GPUS_USING_FRAMELOCK);
     MAKE_BINARY_SIGNAL(NV_CTRL_BINARY_DATA_DISPLAY_VIEWPORT);
     MAKE_BINARY_SIGNAL(NV_CTRL_BINARY_DATA_FRAMELOCKS_USED_BY_GPU);
-    MAKE_BINARY_SIGNAL(NV_CTRL_BINARY_DATA_GPUS_USING_VCSC);
-    MAKE_BINARY_SIGNAL(NV_CTRL_BINARY_DATA_VCSCS_USED_BY_GPU);
     MAKE_BINARY_SIGNAL(NV_CTRL_BINARY_DATA_COOLERS_USED_BY_GPU);
     MAKE_BINARY_SIGNAL(NV_CTRL_BINARY_DATA_GPUS_USED_BY_LOGICAL_XSCREEN);
     MAKE_BINARY_SIGNAL(NV_CTRL_BINARY_DATA_THERMAL_SENSORS_USED_BY_GPU);
